@@ -11,9 +11,9 @@ syntab <- function (veg, clust, type = c('rel','abs','mean.cover'), fullnames=FA
     nb.rel.clust <- as.numeric(table(clust))
 
     if(type=='rel') {
-	tmp <- lapply(sp.veg, function(x) colSums(x > 0))
-	temp <- vector('list', length=ncl)
-	for(i in 1:length(nb.rel.clust))
+    	tmp <- lapply(sp.veg, function(x) colSums(x > 0))
+    	temp <- vector('list', length=ncl)
+	  for(i in 1:length(nb.rel.clust))
 	    temp[[i]] <- round(tmp[[i]] / nb.rel.clust[i] * 100, dec)
     }
     if(type=='mean.cover') {
@@ -25,44 +25,45 @@ syntab <- function (veg, clust, type = c('rel','abs','mean.cover'), fullnames=FA
     st <- as.data.frame(temp)
     st[is.na(st)] <- 0
     names(st) <- levels(clust)
-    if(ncl>1) st <- st[apply(st, 1, function(x) max(x, na.rm=TRUE) > limit),]
+#    if(ncl>1) st <- st[rowSums > limit,]
     if(!is.null(mupa) | class(mupa)=='multipatt' & ncl<1) {
       require(indicspecies)
-      if(class(mupa)!='multipatt')
-	mu <- multipatt(veg, clust, ...) else 
-	mu <- mupa
-      sig <- mu$sign[mu$sign$p.value <= alpha & !is.na(mu$sign$p.value) & mu$sign$stat >= minstat,]
-      
-      st <- st[rownames(sig),]
-      o <- order(sig[,'index'])
-
-      st <- st[o,]
-      st$cl <- attr(mu$str,'dimnames')[[2]][sig[o,'index']]
-      st$stat <- sig$stat[match(rownames(st), rownames(sig))]
-      st$p.value <- sig$p.value[match(rownames(st), rownames(sig))]
+      if(class(mupa)!='multipatt') mu <- multipatt(veg, clust, ...) else mu <- mupa
+      #      st <- st[rownames(st) %in% rownames(sig),]     
+      o <- order(mu$sign[,'index'])
+      df <- mu$sign
+      df[,1:4] <- mu$sign[,1:4] * st
+      colnames(df)[1:ncl] <- levels(clust)
+      st <- df
+#      sig <- mu$sign[mu$sign$p.value <= alpha & !is.na(mu$sign$p.value) & mu$sign$stat >= minstat,]
     }
-    class(st) <- c('syntab','data.frame')
-
+    if(ncl > 1) st <- st[apply(st, 1, function(x) max(x, na.rm=TRUE) > limit), ]
+ #   class(st) <- c('syntab','data.frame')
+    
     if(fullnames) {
       if(missing(refl) & is.null(attr(veg, 'taxreflist'))) stop('Either "taxreflist" attribute must be given in veg object or refl must be specified.')
       if(missing(refl)) refl <- attr(veg, 'taxreflist')
-      nam <- tax(rownames(st), verbose=FALSE, refl, ...)
-      rownames(st) <- nam$ABBREVIAT[match(rownames(st), nam$LETTERCODE)]
+      nam <- tax(rownames(st), verbose=FALSE, syn=FALSE, refl, ...)
+      rownames(st) <- nam$taxonName[match(rownames(st), nam$LETTERCODE)]
       }
-    print(st)
+#    print(st)
     invisible(st)
 }
 
 print.syntab <- function(x, zero.print='.', ...) {
-class(x) <- 'data.frame'
+ class(x) <- 'data.frame'
 if(ncol(x)>1) {
-  if(names(x)[ncol(x)] == 'cl') mu=TRUE else mu=FALSE
-  if(mu) {cl <- x[ncol(x)]; x <- x[-ncol(x)]}
-   if(zero.print != "0" && any(i0 <- x == 0)) {
+  if('stat' %in% names(x)) mu=TRUE else mu=FALSE
+  if(mu) {
+    cl <- x[,'stat']; x <- x[,-which(names(x)=='stat')]
+    index <- x[,'index']; x <- x[,-which(names(x)=='index')]
+    p.value <- x[,'p.value']; x <- x[,-which(names(x)=='p.value')]
+  }
+  if(zero.print != "0" && any(i0 <- x == 0)) {
       x[i0] <- sub("0", zero.print, x[i0])
       x[i0] <- sub("0.0", zero.print, x[i0])
       x[i0] <- sub("0.00", zero.print, x[i0]) }
-  if(mu) x <- cbind(x, cl)
+  if(mu) x <- cbind(x, index, cl, p.value)
  }
    print.data.frame(x, zero.print='', ...)
  }
