@@ -9,7 +9,7 @@
     refl.1 <- tv.refl(db[1])
       for(i in 2:length(db)) {
 	refl.i <- tv.refl(db[i])
-	if(refl.1 != refl.i) stop('Differing taxonomic reference lists used in the databases!')
+	if(refl.1 != refl.i) stop('You are using different taxonomic reference lists in your databases!')
 	obs.tmp <- read.dbf(file.path(tv_home, 'Data', db[i],'tvabund.dbf'))
 	if(any(unique(obs$RELEVE_NR) %in% unique(obs.tmp$RELEVE_NR))) stop('Overlap of releve numbers between the databases!')
 	if(any(!names(obs) %in%  names(obs.tmp))) {
